(Uncle Chat) Free Chat Rooms by Uncle Engineer
==============================================

โปรแกรมแชทนี้เป็นโปรแกรมที่ลุงเขียนขึ้นมาโดยใช้ Python และไลบรารี่
Socket สำหรับใช้งานในการแชทอย่างรวดเร็ว เพียงแค่มี Python
อยู่ในคอมพิวเตอร์ก็สามารถใช้งานได้เลย เบื้องหลังการทำงานลุงมีโปรแกรมฝั่ง
Server รันอยู่บน Server ลุง
สำหรับคอยรับส่งข้อมูลต่อไปยังผู้ใช้งานตามห้องต่างๆที่สร้างขึ้น

หากใครต้องการเรียนพื้นฐานเรื่อง Python Socket
ลุงได้สอนไปอย่างละเอียดระดับหนึ่ง ดูวิดีโอสอนได้ตามลิ้งค์ยูทูปช่องลุง:
https://youtu.be/MEaEVF3ZWfE (ยาว 8 ชั่วโมง 38 นาที) ---> ฝากกด
Subscribe ด้วยจ่ะ!

ปล. เวอร์ชั่นนี้ยังไม่สมบูรณ์ (เขียนแบบรีบๆ 55)
ลุงเขียนขึ้นมาเพื่อประยุกต์นำ Python + Socket Library
สร้างเป็นโปรแกรมแชทตัวอย่าง สำหรับนักพัฒนาสามารถนำ Source Code
ไปพัฒนาต่อได้เต็มที่

วิธีติดตั้ง
~~~~~~~~~~~

เปิด CMD / Terminal

.. code:: python

    pip install unclechat

วิธีใช้
~~~~~~~

[STEP 1] - เปิด IDLE ขึ้นมาแล้วพิมพ์...

.. code:: python

    import unclechat

-  หรือเปิด cmd / terminal แล้วพิมพ์

.. code:: python

    python -m unclechat

[STEP 2] - กรอกชื่อผู้ใช้งานในช่อง Name - กด Enter Chatroom
เพื่อเข้าห้องแชทรวม (เลขห้องแชทรวมคือ 10001)

หากต้องการสร้างห้องใหม่ - กด New Room - โปรแกรมจะสร้างห้องให้อัตโนมัติ
(จำเลขห้องไว้ส่งให้เพื่อน) - กด Enter Chatroom เพื่อเริ่มแชท

[STEP 3] - ใช้งานได้เลยจ้าาา
หากมีการกดปิดโปรแกรมระบบจะแจ้งให้สมาชิกท่านอื่นทราบว่าผู้ใช้ได้ออกจากกลุ่มแล้ว

พัฒนาโดย: ลุงวิศวกร สอนคำนวณ FB: https://www.facebook.com/UncleEngineer
YouTube: https://www.youtube.com/UncleEngineer
